@@ -5,7 +5,7 @@
  * libradius.h	Structures and prototypes
  *		for the radius library.
  *
- * Version:	$Id: libradius.h,v 1.37 2001/07/26 19:10:19 aland Exp $
+ * Version:	$Id: libradius.h,v 1.40 2001/08/29 15:00:05 aland Exp $
  *
  */
 
@@ -76,7 +76,7 @@
 #endif
 
 typedef struct dict_attr {
-	char			name[32];
+	char			name[40];
 	int			attr;
 	int			type;
 	int			vendor;
@@ -84,27 +84,27 @@ typedef struct dict_attr {
 } DICT_ATTR;
 
 typedef struct dict_value {
-	char			name[32];
-	char			attrname[32];
+	char			name[40];
+	char			attrname[40];
 	int			attr;
 	int			value;
 	struct dict_value	*next;
 } DICT_VALUE;
 
 typedef struct dict_vendor {
-	char			vendorname[32];
+	char			vendorname[40];
 	int			vendorpec;
 	int			vendorcode;
 	struct dict_vendor	*next;
 } DICT_VENDOR;
 
 typedef struct value_pair {
-	char			name[32];
+	char			name[40];
 	int			attribute;
 	int			type;
 	int			length; /* of strvalue */
 	uint32_t		lvalue;
-	int			operator;
+	LRAD_TOKEN		operator;
 	int			addport;
 	uint8_t			strvalue[MAX_STRING_LEN];
 	struct value_pair	*next;
@@ -173,12 +173,12 @@ void		librad_md5_calc(u_char *, u_char *, u_int);
 
 /* hmac.c */
 
-void lrad_hmac_md5(unsigned char *text, int text_len,
-		   unsigned char *key, int key_len,
+void lrad_hmac_md5(const unsigned char *text, int text_len,
+		   const unsigned char *key, int key_len,
 		   unsigned char *digest);
 
 /* radius.c */
-int		rad_send(RADIUS_PACKET *, const char *secret);
+int		rad_send(RADIUS_PACKET *, const RADIUS_PACKET *, const char *secret);
 RADIUS_PACKET	*rad_recv(int fd);
 int		rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secret);
 RADIUS_PACKET	*rad_alloc(int newvector);
@@ -201,7 +201,7 @@ void		pairmove(VALUE_PAIR **to, VALUE_PAIR **from);
 void		pairmove2(VALUE_PAIR **to, VALUE_PAIR **from, int attr);
 VALUE_PAIR	*pairmake(const char *attribute, const char *value, int operator);
 VALUE_PAIR	*pairread(char **ptr, int *eol);
-int		userparse(char *buffer, VALUE_PAIR **first_pair);
+LRAD_TOKEN	userparse(char *buffer, VALUE_PAIR **first_pair);
 
 /*
  *	Error functions.
