@@ -1,11 +1,11 @@
 /*
  * radius.c	Functions to send/receive radius packets.
  *
- * Version:	$Id: radius.c,v 1.45 2001/03/12 16:48:14 aland Exp $
+ * Version:	$Id: radius.c,v 1.55 2001/09/05 18:51:24 aland Exp $
  *
  */
 
-static const char rcsid[] = "$Id: radius.c,v 1.45 2001/03/12 16:48:14 aland Exp $";
+static const char rcsid[] = "$Id: radius.c,v 1.55 2001/09/05 18:51:24 aland Exp $";
 
 #include	"autoconf.h"
 
@@ -69,11 +69,17 @@ static const char *packet_codes[] = {
   "Status-Client"
 };
 
+/*
+ *  Internal prototypes
+ */
+static void make_secret(unsigned char *digest, uint8_t *vector,
+			const char *secret, char *value);
+
 /*
  *	Reply to the request.  Also attach
  *	reply attribute value pairs and any user message provided.
  */
-int rad_send(RADIUS_PACKET *packet, const char *secret)
+int rad_send(RADIUS_PACKET *packet, const RADIUS_PACKET *original, const char *secret)
 {
 	VALUE_PAIR		*reply;
 	struct	sockaddr_in	saremote;
@@ -99,6 +105,7 @@ int rad_send(RADIUS_PACKET *packet, const char *secret)
 		  int			vendorcode, vendorpec;
 		  u_short		total_length;
 		  int			len, allowed;
+		  uint8_t		*msg_auth_ptr = NULL;
 		  
 		  hdr = (radius_packet_t *) malloc(PACKET_DATA_LEN);
 		  if (!hdr) {
@@ -142,6 +149,18 @@ int rad_send(RADIUS_PACKET *packet, const char *secret)
 				  continue;
 			  }
 
+			  /*
+			   *	Do stuff for Message-Authenticator
+			   */
+			  if (reply->attribute == PW_MESSAGE_AUTHENTICATOR) {
+				  /*
+				   *  Set it to zero!
+				   */
+				  reply->length = AUTH_VECTOR_LEN;
+				  memset(reply->strvalue, 0, AUTH_VECTOR_LEN);
+				  msg_auth_ptr = ptr;
+			  }
+
 			  /*
 			   *	We have a different vendor.  Re-set
 			   *	the vendor codes.
@@ -179,7 +198,7 @@ int rad_send(RADIUS_PACKET *packet, const char *secret)
 			  if ((vendorcode == 0) &&
 			      ((vendorcode = VENDOR(reply->attribute)) != 0)) {
 				  vendorpec  = dict_vendorpec(vendorcode);
-
+				  
 				  /*
 				   *	This is a potentially bad error...
 				   *	we can't find the vendor ID!
@@ -242,6 +261,19 @@ int rad_send(RADIUS_PACKET *packet, const char *secret)
 			  case PW_TYPE_ABINARY:
 			  case PW_TYPE_STRING:
 			  case PW_TYPE_OCTETS:
+				  /*
+				   *  Hmm... this is based on names
+				   *  right now.  We really shouldn't do
+				   *  this.  It should be based on the value
+				   *  of the attribute (VSA or not).
+				   */
+				  if ((strcmp(reply->name, "Ascend-Send-Secret") == 0) ||
+				      (strcmp(reply->name, "Ascend-Receive-Secret") == 0)) {
+					  make_secret(digest, packet->vector,
+						      secret, reply->strvalue);
+					  memcpy(reply->strvalue, digest, AUTH_VECTOR_LEN );
+					  reply->length = AUTH_VECTOR_LEN;
+				  }
 				  len = reply->length;
 				  
 				  /*
@@ -304,16 +336,73 @@ int rad_send(RADIUS_PACKET *packet, const char *secret)
 		   *	need to calculate the md5 hash over the entire packet
 		   *	and put it in the vector.
 		   */
+		  secretlen = strlen(secret);
 		  if (packet->code != PW_AUTHENTICATION_REQUEST &&
 		      packet->code != PW_STATUS_SERVER) {
-		  	secretlen = strlen(secret);
+		      /*
+		       *	Set the Message-Authenticator attribute,
+		       *	BEFORE setting the reply authentication vector
+		       *	for CHALLENGE, ACCEPT and REJECT.
+		       */
+		      if (msg_auth_ptr) {
+			      uint8_t calc_auth_vector[AUTH_VECTOR_LEN];
+
+			      switch (packet->code) {
+			      default:
+				break;
+				
+			      case PW_AUTHENTICATION_ACK:
+			      case PW_AUTHENTICATION_REJECT:
+			      case PW_ACCESS_CHALLENGE:
+				if (original) {
+				  memcpy(hdr->vector, original->vector, AUTH_VECTOR_LEN);
+				}
+				break;
+			      }
+
+			      memset(msg_auth_ptr + 2, 0, AUTH_VECTOR_LEN);
+			      lrad_hmac_md5(packet->data, packet->data_len,
+					    secret, secretlen, calc_auth_vector);
+			      memcpy(msg_auth_ptr + 2, calc_auth_vector, AUTH_VECTOR_LEN);
+			      memcpy(hdr->vector, packet->vector, AUTH_VECTOR_LEN);
+		        }
 			memcpy((char *)hdr + packet->data_len, secret, secretlen);
 			librad_md5_calc(digest, (unsigned char *)hdr,
 					packet->data_len + secretlen);
 			memcpy(hdr->vector, digest, AUTH_VECTOR_LEN);
+			memcpy(packet->vector, digest, AUTH_VECTOR_LEN);
 			memset((char *)hdr + packet->data_len, 0, secretlen);
 		  }
 
+		  /*
+		   *	Set the Message-Authenticator attribute,
+		   *	AFTER setting the authentication vector
+		   *	only for ACCESS-REQUESTS
+		   */
+		  else if (msg_auth_ptr) {
+			  uint8_t calc_auth_vector[AUTH_VECTOR_LEN];
+
+			  switch (packet->code) {
+			  default:
+			    break;
+			    
+			  case PW_AUTHENTICATION_ACK:
+			  case PW_AUTHENTICATION_REJECT:
+			  case PW_ACCESS_CHALLENGE:
+			    if (original) {
+			      memcpy(hdr->vector, original->vector, AUTH_VECTOR_LEN);
+			    }
+			    break;
+			  }
+
+			  memset(msg_auth_ptr + 2, 0, AUTH_VECTOR_LEN);
+			  lrad_hmac_md5(packet->data, packet->data_len,
+					secret, secretlen, calc_auth_vector);
+			  memcpy(msg_auth_ptr + 2, calc_auth_vector, AUTH_VECTOR_LEN);
+			  memcpy(hdr->vector, packet->vector, AUTH_VECTOR_LEN);
+		  }
+
+
 		  /*
 		   *	If packet->data points to data, then we print out
 		   *	the VP list again only for debugging.
@@ -418,6 +507,7 @@ RADIUS_PACKET *rad_recv(int fd)
 	int			count;
 	radius_packet_t		*hdr;
 	char			host_ipaddr[16];
+	int			seen_eap;
 
 	/*
 	 *	Allocate the new request data structure
@@ -510,6 +600,8 @@ RADIUS_PACKET *rad_recv(int fd)
 	 */
 	attr = hdr->data;
 	count = totallen - AUTH_HDR_LEN;
+	seen_eap = 0;
+
 	while (count > 0) {
 		/*
 		 *	Attribute number zero is NOT defined.
@@ -534,6 +626,38 @@ RADIUS_PACKET *rad_recv(int fd)
 			free(packet);
 			return NULL;
 		}
+
+		/*
+		 *	Sanity check the attributes for length.
+		 */
+		switch (attr[0]) {
+		default:	/* don't do anything by default */
+			break;
+
+		case PW_EAP_MESSAGE:
+			seen_eap |= PW_EAP_MESSAGE;
+			break;
+
+		case PW_MESSAGE_AUTHENTICATOR:
+			if (attr[1] != 2 + AUTH_VECTOR_LEN) {
+				librad_log("Malformed RADIUS packet from host %s: Message-Authenticator has invalid length %d",
+					   ip_ntoa(host_ipaddr, packet->src_ipaddr),
+					   attr[1] - 2);
+				free(packet->data);
+				free(packet);
+				return NULL;
+			}
+			seen_eap |= PW_MESSAGE_AUTHENTICATOR;
+			break;
+		}
+
+		/*
+		 *	FIXME: Look up the base 255 attributes in the
+		 *	dictionary, and switch over their type.  For
+		 *	integer/date/ip, the attribute length SHOULD
+		 *	be 6.
+		 */
+
 		count -= attr[1];	/* grab the attribute length */
 		attr += attr[1];
 	}
@@ -551,6 +675,19 @@ RADIUS_PACKET *rad_recv(int fd)
 		return NULL;
 	}
 
+	/*
+	 *	If we've seen an EAP-Message attribute without a
+	 *	Message-Authenticator attribute, it's invalid.
+	 */
+	if (((seen_eap & PW_EAP_MESSAGE) == PW_EAP_MESSAGE) &&
+	    ((seen_eap & PW_MESSAGE_AUTHENTICATOR) != PW_MESSAGE_AUTHENTICATOR)) {
+		librad_log("Malformed RADIUS packet from host %s: Contains EAP-Message, but no Message-Authenticator",
+			   ip_ntoa(host_ipaddr, packet->src_ipaddr));
+		free(packet->data);
+		free(packet);
+		return NULL;
+	}
+
 	if (librad_debug) {
 		if ((hdr->code > 0) && (hdr->code < 14)) {
 			printf("rad_recv: %s packet from host %s:%d",
@@ -594,11 +731,70 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secre
 	radius_packet_t		*hdr;
 
 	hdr = (radius_packet_t *)packet->data;
-	length = packet->data_len;
+
+	/*
+	 *	Before we allocate memory for the attributes, do more
+	 *	sanity checking.
+	 */
+	ptr = hdr->data;
+	length = packet->data_len - AUTH_HDR_LEN;
+	while (length > 0) {
+		uint8_t	msg_auth_vector[AUTH_VECTOR_LEN];
+		uint8_t calc_auth_vector[AUTH_VECTOR_LEN];
+
+		attrlen = ptr[1];
+
+		switch (ptr[0]) {
+		default:	/* don't do anything. */
+			break;
+
+			/*
+			 *	Note that more than one Message-Authenticator
+			 *	attribute is invalid.
+			 */
+		case PW_MESSAGE_AUTHENTICATOR:
+			memcpy(msg_auth_vector, &ptr[2], sizeof(msg_auth_vector));
+			memset(&ptr[2], 0, AUTH_VECTOR_LEN);
+
+			switch (packet->code) {
+			default:
+			  break;
+
+			case PW_AUTHENTICATION_ACK:
+			case PW_AUTHENTICATION_REJECT:
+			case PW_ACCESS_CHALLENGE:
+			  if (original) {
+				  memcpy(packet->data + 4, original->vector, AUTH_VECTOR_LEN);
+			  }
+			  break;
+			}
+
+			lrad_hmac_md5(packet->data, packet->data_len,
+				      secret, strlen(secret), calc_auth_vector);
+			if (memcmp(calc_auth_vector, msg_auth_vector,
+				    sizeof(calc_auth_vector)) != 0) {
+				char buffer[32];
+				librad_log("Received packet from %s with invalid Message-Authenticator!",
+					   ip_ntoa(buffer, packet->src_ipaddr));
+				return 1;
+			} /* else the message authenticator was good */
+
+			/*
+			 *	Reinitialize Authenticators.
+			 */
+			memcpy(&ptr[2], msg_auth_vector, AUTH_VECTOR_LEN);
+			memcpy(packet->data + 4, packet->vector, AUTH_VECTOR_LEN);
+			break;
+		} /* switch over the attributes */
+
+		ptr += attrlen;
+		length -= attrlen;
+	} /* loop over the packet, sanity checking the attributes */
 
 	/*
 	 *	Calculate and/or verify digest.
 	 */
+	length = packet->data_len;
 	switch(packet->code) {
 		case PW_AUTHENTICATION_REQUEST:
 		case PW_STATUS_SERVER:
@@ -607,11 +803,12 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secre
 			 *	nonsense, invented by the client.
 			 */
 			break;
+
 		case PW_ACCOUNTING_REQUEST:
 			if (calc_acctdigest(packet, secret,
 			    (char *)packet->data, length) > 1) {
 				char buffer[32];
-				librad_log("Received accounting packet "
+				librad_log("Received Accounting-Request packet "
 				    "from %s with invalid signature!",
 				    ip_ntoa(buffer, packet->src_ipaddr));
 				return 1;
@@ -621,29 +818,25 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secre
 			/* Verify the reply digest */
 		case PW_AUTHENTICATION_ACK:
 		case PW_AUTHENTICATION_REJECT:
+		case PW_ACCOUNTING_RESPONSE:
 			if (calc_replydigest(packet, original, secret,
 					     (char *)packet->data,
 					     length) > 1) {
 				char buffer[32];
-				librad_log("Received authentication reply packet "
+				librad_log("Received %s packet "
 					   "from %s with invalid signature!",
+					   packet_codes[packet->code],
 					   ip_ntoa(buffer, packet->src_ipaddr));
 				return 1;
 			}
 		  break;
-
-		case PW_ACCOUNTING_RESPONSE:
-			/*
-			 *	FIXME!  Calculate the response digest!
-			 */
-			break;
 	}
 
 	/*
 	 *	Extract attribute-value pairs
 	 */
 	ptr = hdr->data;
-	length -= AUTH_HDR_LEN;
+	length = packet->data_len - AUTH_HDR_LEN;
 	first_pair = NULL;
 	prev = NULL;
 
@@ -658,10 +851,7 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secre
 			attribute = *ptr++;
 			attrlen   = *ptr++;
 		}
-		if (attrlen < 2) { /* rad_recv() now handles this check */
-			length = 0;
-			continue;
-		}
+
 		attrlen -= 2;
 		length  -= 2;
 
@@ -700,88 +890,93 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original, const char *secre
 			 */
 		}
 
-		if ( attrlen >= MAX_STRING_LEN ) {
-			DEBUG("attribute %d too long, %d >= %d\n", attribute,
-				attrlen, MAX_STRING_LEN);
+		/*
+		 *	FIXME: should we us paircreate() ?
+		 */
+		if ((pair = malloc(sizeof(VALUE_PAIR))) == NULL) {
+			pairfree(&first_pair);
+			librad_log("out of memory");
+			errno = ENOMEM;
+			return -1;
 		}
-		/* rad_recv() now handles this check */
-		else if ( attrlen > length ) {
-			DEBUG("attribute %d longer than buffer left, %d > %d\n",
-				attribute, attrlen, length);
+		
+		memset(pair, 0, sizeof(VALUE_PAIR));
+		if ((attr = dict_attrbyvalue(attribute)) == NULL) {
+			snprintf(pair->name, sizeof(pair->name), "Attr-%d", attribute);
+			pair->type = PW_TYPE_STRING;
+		} else {
+			strcpy(pair->name, attr->name);
+			pair->type = attr->type;
 		}
-		else {
+		pair->attribute = attribute;
+		pair->length = attrlen;
+		pair->next = NULL;
+		
+		switch (pair->type) {
+			
+		case PW_TYPE_OCTETS:
+		case PW_TYPE_ABINARY:
+		case PW_TYPE_STRING:
 			/*
-			 *	FIXME: should we us paircreate() ?
+			 *	Hmm... this is based on names right
+			 *	now.  We really shouldn't do this.
+			 *	It should be based on the value of
+			 *	the attribute (VSA or not).
 			 */
-			if ((pair = malloc(sizeof(VALUE_PAIR))) == NULL) {
-				pairfree(&first_pair);
-				librad_log("out of memory");
-				errno = ENOMEM;
-				return -1;
-			}
-
-			memset(pair, 0, sizeof(VALUE_PAIR));
-			if ((attr = dict_attrbyvalue(attribute)) == NULL) {
-				snprintf(pair->name, sizeof(pair->name), "Attr-%d", attribute);
-				pair->type = PW_TYPE_STRING;
-			} else {
-				strcpy(pair->name, attr->name);
-				pair->type = attr->type;
-			}
-			pair->attribute = attribute;
-			pair->length = attrlen;
-			pair->next = NULL;
-
-			switch (pair->type) {
-
-			case PW_TYPE_OCTETS:
-			case PW_TYPE_ABINARY:
-			case PW_TYPE_STRING:
+			if ((strcmp(pair->name, "Ascend-Send-Secret") == 0) ||
+			    (strcmp(pair->name, "Ascend-Receive-Secret") == 0)) {
+				uint8_t my_digest[AUTH_VECTOR_LEN];
+				make_secret( my_digest, original->vector,
+					     secret, ptr);
+				memcpy(pair->strvalue, my_digest, AUTH_VECTOR_LEN );
+				pair->strvalue[AUTH_VECTOR_LEN] = '\0';
+				pair->length = strlen(pair->strvalue);
+			} else
 				/* attrlen always < MAX_STRING_LEN */
 				memcpy(pair->strvalue, ptr, attrlen);
-				break;
+			break;
 			
-			case PW_TYPE_INTEGER:
-			case PW_TYPE_DATE:
-			case PW_TYPE_IPADDR:
-				/*
-				 *	Check for RFC compliance.
-				 *	If the attribute isn't compliant,
-				 *	turn it into a string of raw octets.
-				 *
-				 *	Also set the lvalue to something
-				 *	which should never match anything.
-				 */
-				if (attrlen != 4) {
-					pair->type = PW_TYPE_OCTETS;
-					memcpy(pair->strvalue, ptr, attrlen);
-					pair->lvalue = 0xbaddbadd;
-					break;
-				}
-				memcpy(&lvalue, ptr, 4);
-				if (attr->type != PW_TYPE_IPADDR)
-					pair->lvalue = ntohl(lvalue);
-				else
-					pair->lvalue = lvalue;
-				break;
-			
-			default:
-				DEBUG("    %s (Unknown Type %d)\n",
-					attr->name,attr->type);
-				free(pair);
-				pair = NULL;
+		case PW_TYPE_INTEGER:
+		case PW_TYPE_DATE:
+		case PW_TYPE_IPADDR:
+			/*
+			 *	Check for RFC compliance.  If the
+			 *	attribute isn't compliant, turn it
+			 *	into a string of raw octets.
+			 *
+			 *	Also set the lvalue to something
+			 *	which should never match anything.
+			 */
+			if (attrlen != 4) {
+				pair->type = PW_TYPE_OCTETS;
+				memcpy(pair->strvalue, ptr, attrlen);
+				pair->lvalue = 0xbaddbadd;
 				break;
 			}
-
-			if (pair) {
-				debug_pair(pair);
-				if (first_pair == NULL)
-					first_pair = pair;
-				else
-				  	prev->next = pair;
-				prev = pair;
-			}
+			memcpy(&lvalue, ptr, 4);
+			if (attr->type != PW_TYPE_IPADDR)
+				pair->lvalue = ntohl(lvalue);
+			else
+				pair->lvalue = lvalue;
+			break;
+			
+		default:
+			DEBUG("    %s (Unknown Type %d)\n",
+			      attr->name,attr->type);
+			free(pair);
+			pair = NULL;
+			break;
 		}
+		
+		if (pair) {
+			debug_pair(pair);
+			if (first_pair == NULL)
+				first_pair = pair;
+			else
+				  	prev->next = pair;
+			prev = pair;
+		}
+
 		ptr += attrlen;
 		length -= attrlen;
 		if (vendorlen > 0) vendorlen -= (attrlen + 2);
@@ -1092,3 +1287,32 @@ void rad_free(RADIUS_PACKET **radius_packet_ptr)
 
 	*radius_packet_ptr = NULL;
 }
+
+/*************************************************************************
+ *
+ *      Function: make_secret
+ *
+ *      Purpose: Build an encrypted secret value to return in a reply
+ *               packet.  The secret is hidden by xoring with a MD5 digest
+ *               created from the shared secret and the authentication
+ *               vector.  We put them into MD5 in the reverse order from
+ *               that used when encrypting passwords to RADIUS.
+ *
+ *************************************************************************/
+static void make_secret(unsigned char *digest, uint8_t *vector,
+			const char *secret, char *value)
+{
+        u_char  buffer[256 + AUTH_VECTOR_LEN];
+        int             secretLen = strlen(secret);
+        int             i;
+
+        memcpy(buffer, vector, AUTH_VECTOR_LEN );
+        memcpy(buffer + AUTH_VECTOR_LEN, secret, secretLen );
+
+        librad_md5_calc(digest, buffer, AUTH_VECTOR_LEN + secretLen );
+        memset(buffer, 0, sizeof(buffer));
+
+        for ( i = 0; i < AUTH_VECTOR_LEN; i++ ) {
+		digest[i] ^= value[i];
+        }
+}
