@@ -1,11 +1,11 @@
 /*
  * valuepair.c	Functions to handle VALUE_PAIRs
  *
- * Version:	$Id: valuepair.c,v 1.39 2001/03/07 22:30:52 cmiller Exp $
+ * Version:	$Id: valuepair.c,v 1.42 2001/09/06 16:14:43 aland Exp $
  *
  */
 
-static const char rcsid[] = "$Id: valuepair.c,v 1.39 2001/03/07 22:30:52 cmiller Exp $";
+static const char rcsid[] = "$Id: valuepair.c,v 1.42 2001/09/06 16:14:43 aland Exp $";
 
 #include	"autoconf.h"
 
@@ -377,6 +377,11 @@ void pairmove2(VALUE_PAIR **to, VALUE_PAIR **from, int attr)
 	for(i = *from; i; i = next) {
 		next = i->next;
 
+
+		/*
+		 *	FIXME: Do we want to match *any* VSA if
+		 *	'attr == PW_VENDOR_SPECIFIC' ???
+		 */
 		if (i->attribute != attr) {
 			iprev = i;
 			continue;
@@ -452,7 +457,7 @@ static int gettime(const char *valstr, time_t *lvalue)
 
 	tm->tm_mon = 12;
 	for (i = 0; i < 12; i++) {
-		if (strncmp(months[i], month, 3) == 0) {
+		if (strncasecmp(months[i], month, 3) == 0) {
 			tm->tm_mon = i;
 			break;
 		}
@@ -462,6 +467,10 @@ static int gettime(const char *valstr, time_t *lvalue)
 	if (tm->tm_mon == 12) return -1;
 
 	tm->tm_mday = atoi(day);
+	if ((tm->tm_mday < 1) || (tm->tm_mday > 31)) {
+		return -1;
+	}
+
 	tm->tm_year = atoi(year);
 	if (tm->tm_year >= 1900) tm->tm_year -= 1900;
 
@@ -620,7 +629,7 @@ VALUE_PAIR *pairread(char **ptr, int *eol)
 	char		attr[64];
 	char		value[256];
 	char		*p;
-	int		token, t;
+	LRAD_TOKEN	token, t;
 
 	*eol = 0;
 
@@ -676,24 +685,24 @@ VALUE_PAIR *pairread(char **ptr, int *eol)
  *	Read one line of attribute/value pairs. This might contain
  *	multiple pairs seperated by comma's.
  */
-int userparse(char *buffer, VALUE_PAIR **first_pair)
+LRAD_TOKEN userparse(char *buffer, VALUE_PAIR **first_pair)
 {
 	VALUE_PAIR	*vp;
 	char		*p;
-	int		last_token = 0;
-	int		previous_token;
+	LRAD_TOKEN	last_token = T_INVALID;
+	LRAD_TOKEN	previous_token;
 
 	/*
 	 *	We allow an empty line.
 	 */
 	if (buffer[0] == 0)
-		return 0;
+		return T_EOL;
 
 	p = buffer;
 	do {
 		previous_token = last_token;
 		if ((vp = pairread(&p, &last_token)) == NULL) {
-			return -1;
+			return T_INVALID;
 		}
 		pairadd(first_pair, vp);
 	} while (*p && (last_token == T_COMMA));
