@@ -1,7 +1,7 @@
 /*
  * auth.c	User authentication.
  *
- * Version:	$Id: auth.c,v 1.83 2001/07/28 00:42:15 cparker Exp $
+ * Version:	$Id: auth.c,v 1.90 2001/09/17 19:25:43 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  */
 
-static const char rcsid[] = "$Id: auth.c,v 1.83 2001/07/28 00:42:15 cparker Exp $";
+static const char rcsid[] = "$Id: auth.c,v 1.90 2001/09/17 19:25:43 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -35,11 +35,6 @@ static const char rcsid[] = "$Id: auth.c,v 1.83 2001/07/28 00:42:15 cparker Exp
 #	include <crypt.h>
 #endif
 
-#ifdef OSFC2
-#	include <sys/security.h>
-#	include <prot.h>
-#endif
-
 #if HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
@@ -119,23 +114,19 @@ static int rad_authlog(const char *msg, REQUEST *request, int goodpass) {
 	char clean_username[1024];
 	char buf[1024];
 
-	if (!mainconfig.log_auth)
+	if (!mainconfig.log_auth) {
 		return 0;
+	}
 
 	/* 
 	 *	Clean up the username
 	 */
 	if (request->username == NULL) {
-		DEBUG2("rad_authlog:  no username found");
-		return -1;
-	}
-
-	if (request->username->strvalue) {
+		strcpy(clean_username, "<no User-Name attribute>");
+	} else {
 		librad_safeprint((char *)request->username->strvalue,
 				request->username->length,
 				clean_username, sizeof(clean_username));
-	} else {
-		strcpy(clean_username, "<No Username>");
 	}
 
 	/* 
@@ -143,20 +134,13 @@ static int rad_authlog(const char *msg, REQUEST *request, int goodpass) {
 	 */
 	if (mainconfig.log_auth_badpass || mainconfig.log_auth_goodpass) {
 		if (!request->password) {
-			DEBUG2("rad_authlog:  no password found");
-			return -1;
-		}
-
-		if (request->password->attribute == PW_CHAP_PASSWORD) {
+			strcpy(clean_password, "<no Password attribute>");
+		} else if (request->password->attribute == PW_CHAP_PASSWORD) {
 			strcpy(clean_password, "<CHAP-Password>");
 		} else {
-			if (request->username->strvalue) {
-				librad_safeprint((char *)request->password->strvalue,
-						 request->password->length,
-						 clean_password, sizeof(clean_password));
-			} else {
-				strcpy(clean_password, "<No Password>");
-			}
+			librad_safeprint((char *)request->password->strvalue,
+					 request->password->length,
+					 clean_password, sizeof(clean_password));
 		}
 	}
 
@@ -232,7 +216,7 @@ int rad_check_password(REQUEST *request)
 		auth_type = auth_type_pair->lvalue;
 		auth_type_count++;
 
-		DEBUG2("  rad_check_password:  Found auth-type %s",
+		DEBUG2("  rad_check_password:  Found Auth-Type %s",
 				auth_type_pair->strvalue);
 		cur_config_item = auth_type_pair->next;
 
@@ -242,7 +226,7 @@ int rad_check_password(REQUEST *request)
 		}
 	}
 
-	if((auth_type_count>1) && (debug_flag)) {
+	if (( auth_type_count > 1) && (debug_flag)) {
 		radlog(L_ERR, "Warning:  Found %d auth-types on request for user '%s'", 
 			auth_type_count, request->username->strvalue);
 	}
@@ -264,7 +248,7 @@ int rad_check_password(REQUEST *request)
 	 */
 	auth_item = request->password;
 	if (auth_item == NULL) {
-		DEBUG2("auth: No password in the request");
+		DEBUG2("auth: No Password or CHAP-Password attribute in the request");
 		return -1;
 	}
 
@@ -279,57 +263,74 @@ int rad_check_password(REQUEST *request)
 	/*
 	 *	For backward compatibility, we check the
 	 *	password to see if it is the magic value
-	 *	UNIX if auth_type was not set.
+	 *	UNIX or PAM if auth_type was not set.
+	 *
+	 *	This allows the admin to just put a 'Password' in, and
+	 *	have it work.
 	 */
 	if (auth_type < 0) {
-		if (password_pair &&
-		    !strcmp((char *)password_pair->strvalue, "UNIX"))
-			auth_type = PW_AUTHTYPE_SYSTEM;
-		else if(password_pair &&
-			!strcmp((char *)password_pair->strvalue,"PAM"))
-			auth_type = PW_AUTHTYPE_PAM;
-		else
-			auth_type = PW_AUTHTYPE_LOCAL;
+		if (password_pair) {
+			if (!strcmp((char *)password_pair->strvalue, "UNIX"))
+				auth_type = PW_AUTHTYPE_SYSTEM;
+			else if (!strcmp((char *)password_pair->strvalue,"PAM"))
+				auth_type = PW_AUTHTYPE_PAM;
+			else
+				auth_type = PW_AUTHTYPE_LOCAL;
+		} else {
+			/*
+			 *	The admin hasn't told us how to
+			 *	authenticate the user, so we reject them!
+			 *
+			 *	This is fail-safe.
+			 */
+			DEBUG2("auth: No Auth-Type configuration for the request, rejecting the user");
+			return -2;
+		}
 	}
 
 	switch(auth_type) {
 		case PW_AUTHTYPE_CRYPT:
 			DEBUG2("auth: type Crypt");
 			if (password_pair == NULL) {
-				result = auth_item->strvalue ? -1 : 0;
-				break;
+				DEBUG2("No Crypt-Password configured for the user");
+				rad_authlog("No Crypt-Password configured for the user", request, 0);
+				return -1;
 			}
+					
 			if (strcmp((char *)password_pair->strvalue,
-					crypt((char *)auth_item->strvalue,
-							(char *)password_pair->strvalue)) != 0)
+				   crypt((char *)auth_item->strvalue,
+					 (char *)password_pair->strvalue)) != 0)
 				result = -1;
 			break;
 		case PW_AUTHTYPE_LOCAL:
 			DEBUG2("auth: type Local");
+
+			/*
+			 *	Plain text password.
+			 */
+			if (password_pair == NULL) {
+				DEBUG2("auth: No Password configured for the user");
+				rad_authlog("No Password configured for the user", request, 0);
+				return -1;
+			}
+
 			/*
 			 *	Local password is just plain text.
 	 		 */
-			if (auth_item->attribute != PW_CHAP_PASSWORD) {
-
-				/*
-				 *	Plain text password.
-				 */
-				if (password_pair == NULL ||
-						strcmp((char *)password_pair->strvalue,
-								(char *)auth_item->strvalue)!=0)
-					result = -1;
+			if (auth_item->attribute == PW_PASSWORD) {
+				if (strcmp((char *)password_pair->strvalue,
+					   (char *)auth_item->strvalue) != 0) {
+					return -1;
+				}
+				DEBUG2("auth: user supplied Password matches local Password");
 				break;
+
+			} else if (auth_item->attribute != PW_CHAP_PASSWORD) {
+				DEBUG2("The user did not supply a Password or a CHAP-Password attribute");
+				rad_authlog("The user did not supply a Password or a CHAP-Password attribute", request, 0);
+				return -1;
 			}
 
-			/*
-			 *	CHAP - calculate MD5 sum over CHAP-ID,
-			 *	plain-text password and the Chap-Challenge.
-			 *	Compare to Chap-Response (strvalue + 1).
-			 */
-			if (password_pair == NULL) {
-				result= -1;
-				break;
-			}
 			rad_chap_encode(request->packet, string,
 					auth_item->strvalue[0], password_pair);
 
@@ -339,6 +340,7 @@ int rad_check_password(REQUEST *request)
 			if (memcmp(string + 1, auth_item->strvalue + 1,
 					CHAP_VALUE_LENGTH) != 0)
 				result = -1;
+			DEBUG2("auth: user supplied CHAP-Password matches local Password");
 			break;
 		default:
 			DEBUG2("auth: type \"%s\"",
@@ -399,7 +401,6 @@ int rad_authenticate(REQUEST *request)
 	char		*exec_program;
 	int		exec_wait;
 	int		seen_callback_id;
-	int 		nas_port = 0;
 	char		buf[1024], logstr[1024];
 
 	password = "";
@@ -421,7 +422,7 @@ int rad_authenticate(REQUEST *request)
 	 *	pairs from the server to the initial reply.
 	 */
 	if ((request->proxy_reply) &&
-			(request->packet->code == PW_AUTHENTICATION_REQUEST)) {
+	    (request->packet->code == PW_AUTHENTICATION_REQUEST)) {
 		tmp = paircreate(PW_AUTHTYPE, PW_TYPE_INTEGER);
 		if (tmp == NULL) {
 			radlog(L_ERR|L_CONS, "no memory");
@@ -432,7 +433,8 @@ int rad_authenticate(REQUEST *request)
 		 *	Reply of ACCEPT means accept, ALL other
 		 *	replies mean reject.  This is fail-safe.
 		 */
-		if (request->proxy_reply->code == PW_AUTHENTICATION_ACK)
+		if ((request->proxy_reply->code == PW_AUTHENTICATION_ACK) ||
+		    (request->proxy_reply->code == PW_ACCESS_CHALLENGE))
 			tmp->lvalue = PW_AUTHTYPE_ACCEPT;
 		else
 			tmp->lvalue = PW_AUTHTYPE_REJECT;
@@ -444,6 +446,7 @@ int rad_authenticate(REQUEST *request)
 		 */
 		if (request->proxy_reply->vps) {
 			request->reply->vps = request->proxy_reply->vps;
+			request->reply->code = request->proxy_reply->code;
 			request->proxy_reply->vps = NULL;
 		}
 
@@ -453,7 +456,9 @@ int rad_authenticate(REQUEST *request)
 		 *	rejected, so we minimize the amount of work
 		 *	done by the server, by rejecting them here.
 		 */
-		if (request->proxy_reply->code != PW_AUTHENTICATION_ACK) {
+		if ((request->proxy_reply->code != PW_AUTHENTICATION_ACK) &&
+		    (request->proxy_reply->code != PW_ACCESS_CHALLENGE)) {
+			rad_authlog("Home server says invalid user", request, 0);
 			request->reply->code = PW_AUTHENTICATION_REJECT;
 			return RLM_MODULE_REJECT;
 		}
@@ -677,32 +682,20 @@ int rad_authenticate(REQUEST *request)
 
 	/*
 	 *	Add the port number to the Framed-IP-Address if
-	 *	vp->addport is set, or if the Add-Port-To-IP-Address
-	 *	pair is present.
-	 *
-	 *	FIXME:  This doesn't work because PW_ADD_PORT_TO_IP_ADDRESS
-	 *	is never added to the request pairs!
+	 *	vp->addport is set.
 	 */
-	if ((tmp = pairfind(request->reply->vps, 
-			PW_FRAMED_IP_ADDRESS)) != NULL) {
+	if (((tmp = pairfind(request->reply->vps, 
+			    PW_FRAMED_IP_ADDRESS)) != NULL) &&
+	    (tmp->addport != 0)) {
 		VALUE_PAIR *vpPortId;
-		VALUE_PAIR *vpAddPort;
-
+		
 		/*
 		 *  Find the NAS port ID.
 		 */
 		if ((vpPortId = pairfind(request->packet->vps,
-				PW_NAS_PORT_ID)) != NULL)
-			nas_port = vpPortId->lvalue;
-
-		if((vpAddPort = pairfind(request->reply->vps,
-				PW_ADD_PORT_TO_IP_ADDRESS)) != NULL) {
-			if (tmp->addport || (vpAddPort && vpAddPort->lvalue)) {
-				tmp->lvalue = htonl(ntohl(tmp->lvalue) + nas_port);
-				tmp->addport = 0;
-			}
-			pairdelete(&request->reply->vps,
-					PW_ADD_PORT_TO_IP_ADDRESS);
+					 PW_NAS_PORT_ID)) != NULL) {
+		  tmp->lvalue = htonl(ntohl(tmp->lvalue) + vpPortId->lvalue);
+		  tmp->addport = 0;
 		}
 	}
 
@@ -747,6 +740,8 @@ int rad_authenticate(REQUEST *request)
 	if (exec_program && exec_wait) {
 		if (radius_exec_program(exec_program, request,
 				exec_wait, &user_msg) != 0) {
+			free(exec_program);
+
 			/*
 			 *	Error. radius_exec_program() returns -1 on
 			 *	fork/exec errors, or >0 if the exec'ed program
@@ -806,7 +801,12 @@ int rad_authenticate(REQUEST *request)
 		}
 	}
 
-	request->reply->code = PW_AUTHENTICATION_ACK;
+	/*
+	 *	Set the reply to Access-Accept, if it hasn't already
+	 *	been set to something.  (i.e. Access-Challenge)
+	 */
+	if (request->reply->code == 0)
+	  request->reply->code = PW_AUTHENTICATION_ACK;
 
 	rad_authlog("Login OK", request, 1);
 	if (exec_program && !exec_wait) {
