@@ -5,7 +5,7 @@
  *		write a decent parser. I know how to do that, really :)
  *		miquels@cistron.nl
  *
- * Version:	$Id: conffile.c,v 1.70 2001/07/01 19:18:19 cmiller Exp $
+ * Version:	$Id: conffile.c,v 1.74 2001/09/20 18:09:36 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,19 +31,19 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <assert.h>
 
 #if HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
 
 #include "radiusd.h"
+#include "rad_assert.h"
 #include "conffile.h"
 #include "token.h"
 #include "modules.h"
 
 static const char rcsid[] =
-"$Id: conffile.c,v 1.70 2001/07/01 19:18:19 cmiller Exp $";
+"$Id: conffile.c,v 1.74 2001/09/20 18:09:36 aland Exp $";
 
 #define xstrdup strdup
 
@@ -62,7 +62,7 @@ struct conf_pair {
 	CONF_ITEM item;
 	char *attr;
 	char *value;
-	int operator;
+	LRAD_TOKEN operator;
 };
 struct conf_part {
 	CONF_ITEM item;
@@ -95,14 +95,14 @@ CONF_PAIR *cf_itemtopair(CONF_ITEM *ci)
 {
 	if (ci == NULL)
 		return NULL;
-	assert(ci->type == CONF_ITEM_PAIR);
+	rad_assert(ci->type == CONF_ITEM_PAIR);
 	return (CONF_PAIR *)ci;
 }
 CONF_SECTION *cf_itemtosection(CONF_ITEM *ci)
 {
 	if (ci == NULL)
 		return NULL;
-	assert(ci->type == CONF_ITEM_SECTION);
+	rad_assert(ci->type == CONF_ITEM_SECTION);
 	return (CONF_SECTION *)ci;
 }
 CONF_ITEM *cf_pairtoitem(CONF_PAIR *cp)
@@ -122,7 +122,7 @@ CONF_ITEM *cf_sectiontoitem(CONF_SECTION *cs)
  *	Create a new CONF_PAIR
  */
 static CONF_PAIR *cf_pair_alloc(const char *attr, const char *value,
-		int operator, CONF_SECTION *parent)
+		LRAD_TOKEN operator, CONF_SECTION *parent)
 {
 	CONF_PAIR *cp;
 
@@ -639,7 +639,7 @@ static CONF_SECTION *cf_section_read(const char *cf, int *lineno, FILE *fp,
 		 */
 		if (buf1[0] != 0 && buf2[0] == 0 && buf3[0] == 0) {
 			t2 = T_OP_EQ;
-		} else if (buf1[0] == 0 || buf2[0] == 0 || buf3[0] == 0 ||
+		} else if (buf1[0] == 0 || buf2[0] == 0 || 
 					(t2 < T_EQSTART || t2 > T_EQEND)) {
 			radlog(L_ERR, "%s[%d]: Line is not in 'attribute = value' format",
 					cf, *lineno);
@@ -841,9 +841,11 @@ int read_radius_conf_file(void)
 static int generate_realms(const char *filename)
 {
 	CONF_SECTION *cs;
-	REALM *c;
+	REALM *my_realms = NULL;
+	REALM *c, **tail;
 	char *s, *authhost, *accthost;
 
+	tail = &my_realms;
 	for (cs = cf_subsection_find_next(config, NULL, "realm"); cs != NULL;
 			cs = cf_subsection_find_next(config, cs, "realm")) {
 		if (!cs->name2) {
@@ -931,13 +933,20 @@ static int generate_realms(const char *filename)
 			c->notrealm = 1;
 		if ((cf_section_value_find(cs, "notsuffix")) != NULL)
 			c->notrealm = 1;
+		c->active = TRUE;
 
-
-		c->next = realms;
-		realms = c;
-
+		c->next = NULL;
+		*tail = c;
+		tail = &c->next;
 	}
 
+	/*
+	 *	And make these realms preferred over the ones
+	 *	in the 'realms' file.
+	 */
+	*tail = realms;
+	realms = my_realms;
+
 	return 0;
 }
 
