@@ -1,7 +1,7 @@
 /*
  * log.c	Logging module.
  *
- * Version:	$Id: log.c,v 1.20 2001/05/15 22:29:42 cmiller Exp $
+ * Version:	$Id: log.c,v 1.21 2001/09/12 15:09:42 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2001  Chad Miller <cmiller@surfsouth.com>
  */
 
-static const char rcsid[] = "$Id: log.c,v 1.20 2001/05/15 22:29:42 cmiller Exp $";
+static const char rcsid[] = "$Id: log.c,v 1.21 2001/09/12 15:09:42 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -120,6 +120,15 @@ static int do_log(int lvl, const char *fmt, va_list ap)
 	int use_syslog = FALSE;
 #endif
 
+	/*
+	 *	NOT debugging, and trying to log debug messages.
+	 *
+	 *	Throw the message away.
+	 */
+	if (!debug_flag && (lvl == L_DBG)) {
+		return 0;
+	}
+
 	if (radlog_dir != NULL) {
 		if (debug_flag || (strcmp(radlog_dir, "stdout") == 0)) {
 			msgfd = stdout;
