@@ -1,7 +1,7 @@
 /*
  * modules.c	Radius module support.
  *
- * Version:	$Id: modules.c,v 1.60 2001/07/01 19:18:19 cmiller Exp $
+ * Version:	$Id: modules.c,v 1.62 2001/09/13 20:13:18 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Alan Curry <pacman@world.std.com>
  */
 
-static const char rcsid[] = "$Id: modules.c,v 1.60 2001/07/01 19:18:19 cmiller Exp $";
+static const char rcsid[] = "$Id: modules.c,v 1.62 2001/09/13 20:13:18 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -30,7 +30,6 @@ static const char rcsid[] = "$Id: modules.c,v 1.60 2001/07/01 19:18:19 cmiller E
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <assert.h>
 
 #include "radiusd.h"
 #include "modpriv.h"
@@ -462,9 +461,12 @@ static void load_subcomponent_section(CONF_SECTION *cs, int comp, const char *fi
 {
 	int idx;
 	indexed_modcallable *subcomp;
+	modcallable *ml;
 
 	static int meaningless_counter = 1;
 
+	ml = compile_modgroup(comp, cs, filename);
+
 	/* We must assign a numeric index to this subcomponent. For
 	 * auth, it is generated and placed in the dictionary by
 	 * new_authtype_value(). The others are just numbers that are pulled
@@ -483,10 +485,11 @@ static void load_subcomponent_section(CONF_SECTION *cs, int comp, const char *fi
 				"%s[%d] %s %s already configured - skipping",
 				filename, cf_section_lineno(cs),
 				subcomponent_names[comp], cf_section_name2(cs));
+		modcallable_free(&ml);
 		return;
 	}
 
-	subcomp->modulelist = compile_modgroup(comp, cs, filename);
+	subcomp->modulelist = ml;
 }
 
 static void load_component_section(CONF_SECTION *cs, int comp, const char *filename)
