@@ -1,7 +1,7 @@
 /*
  * proxy.c	Proxy stuff.
  *
- * Version:	$Id: proxy.c,v 1.46 2001/03/14 06:54:54 pacman Exp $
+ * Version:	$Id: proxy.c,v 1.48 2001/08/29 15:00:06 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Chris Parker <cparker@starnetusa.com>
  */
 
-static const char rcsid[] = "$Id: proxy.c,v 1.46 2001/03/14 06:54:54 pacman Exp $";
+static const char rcsid[] = "$Id: proxy.c,v 1.48 2001/08/29 15:00:06 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -37,9 +37,9 @@ static const char rcsid[] = "$Id: proxy.c,v 1.46 2001/03/14 06:54:54 pacman Exp
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
-#include <assert.h>
 
 #include "radiusd.h"
+#include "rad_assert.h"
 
 
 static uint32_t proxy_id = 1;
@@ -254,7 +254,7 @@ int proxy_send(REQUEST *request)
 		request->proxy->dst_port = realm->auth_port;
 	else
 		request->proxy->dst_port = realm->acct_port;
-	assert(request->proxy->vps == NULL);
+	rad_assert(request->proxy->vps == NULL);
 	request->proxy->vps = vps;
 
 	/*
@@ -301,7 +301,7 @@ int proxy_send(REQUEST *request)
 	/*
 	 *	Send the request.
 	 */
-	rad_send(request->proxy, (char *)realm->secret);
+	rad_send(request->proxy, NULL, (char *)realm->secret);
 	memcpy(request->proxysecret, realm->secret, sizeof(request->proxysecret));
 	request->proxy_is_replicate = replicating;
 	request->proxy_try_count = proxy_retry_count - 1;
