@@ -1,7 +1,7 @@
 /*
  * radclient.c	General radius packet debug tool.
  *
- * Version:	$Id: radclient.c,v 1.36 2001/03/05 03:42:11 cmiller Exp $
+ * Version:	$Id: radclient.c,v 1.40 2001/08/29 15:00:06 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Copyright 2000  Miquel van Smoorenburg <miquels@cistron.nl>
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
-static const char rcsid[] = "$Id: radclient.c,v 1.36 2001/03/05 03:42:11 cmiller Exp $";
+static const char rcsid[] = "$Id: radclient.c,v 1.40 2001/08/29 15:00:06 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -56,12 +56,13 @@ static const char rcsid[] = "$Id: radclient.c,v 1.36 2001/03/05 03:42:11 cmiller
 
 static int retries = 10;
 static float timeout = 3;
-static const char *secret = "secret";
+static const char *secret = NULL;
 static int do_output = 1;
 static int do_summary = 0;
 static int filedone = 0;
 static int totalapp = 0;
 static int totaldeny = 0;
+static char filesecret[256];
 
 /*
  *	Read valuepairs from the fp up to End-Of-File.
@@ -105,7 +106,7 @@ static VALUE_PAIR *readvp(FILE *fp)
 static void usage(void)
 {
 	fprintf(stderr, "Usage: radclient [-c count] [-d raddb] [-f file] [-r retries] [-t timeout]\n"
-			"[-i id] [-qvx] server acct|auth <secret>\n");
+			"[-i id] [-qvxS] server acct|auth [<secret>]\n");
 	
 	fprintf(stderr, " -c count    Send each packet 'count' times.\n");
 	fprintf(stderr, " -d raddb    Set dictionary directory.\n");
@@ -113,6 +114,7 @@ static void usage(void)
 	fprintf(stderr, " -r retries  If timeout, retry sending the packet 'retires' times.\n");
 	fprintf(stderr, " -t timeout  Wait 'timeout' seconds before retrying.\n");
 	fprintf(stderr, " -i id       Set request id to 'id'.  Values may be 0..255\n");
+	fprintf(stderr, " -S file     read secret from file, not command line.\n");
 	fprintf(stderr, " -q          Do not print anything out.\n");
 	fprintf(stderr, " -s          Print out summary information of auth results.\n");
 	fprintf(stderr, " -v          Show program version information.\n");
@@ -141,7 +143,7 @@ static int send_packet(RADIUS_PACKET *req, RADIUS_PACKET **rep)
 	for (i = 0; i < retries; i++) {
 		fd_set		rdfdesc;
 
-		rad_send(req, secret);
+		rad_send(req, NULL, secret);
 
 		/* And wait for reply, timing out as necessary */
 		FD_ZERO(&rdfdesc);
@@ -208,7 +210,7 @@ int main(int argc, char **argv)
 
 	id = ((int)getpid() & 0xff);
 
-	while ((c = getopt(argc, argv, "c:d:f:hi:qst:r:xv")) != EOF) switch(c) {
+	while ((c = getopt(argc, argv, "c:d:f:hi:qst:r:S:xv")) != EOF) switch(c) {
 		case 'c':
 			if (!isdigit(*optarg)) 
 				usage();
@@ -248,9 +250,37 @@ int main(int argc, char **argv)
 			timeout = atof(optarg);
 			break;
 		case 'v':
-			printf("radclient: $Id: radclient.c,v 1.36 2001/03/05 03:42:11 cmiller Exp $ built on " __DATE__ " at " __TIME__ "\n");
+			printf("radclient: $Id: radclient.c,v 1.40 2001/08/29 15:00:06 aland Exp $ built on " __DATE__ " at " __TIME__ "\n");
 			exit(0);
 			break;
+               case 'S':
+		       fp = fopen(optarg, "r");
+                       if (!fp) {
+                               fprintf(stderr, "radclient: Error opening %s: %s\n",
+                                       optarg, strerror(errno));
+                               exit(1);
+                       }
+                       if (fgets(filesecret, sizeof(filesecret), fp) == NULL) {
+                               fprintf(stderr, "radclient: Error reading %s: %s\n",
+                                       optarg, strerror(errno));
+                               exit(1);
+                       }
+		       fclose(fp);
+
+                       /* truncate newline */
+		       p = filesecret + strlen(filesecret) - 1;
+		       while ((p >= filesecret) &&
+			      (*p < ' ')) {
+			       *p = '\0';
+			       --p;
+		       }
+
+                       if (strlen(filesecret) < 2) {
+                               fprintf(stderr, "radclient: Secret in %s is too short\n", optarg);
+                               exit(1);
+                       }
+                       secret = filesecret;
+		       break;
 		case 'h':
 		default:
 			usage();
@@ -259,7 +289,8 @@ int main(int argc, char **argv)
 	argc -= (optind - 1);
 	argv += (optind - 1);
 
-	if (argc < 4) {
+	if ((argc < 3)  ||
+	    ((secret == NULL) && (argc < 4))) {
 		usage();
 	}
 
@@ -351,23 +382,15 @@ int main(int argc, char **argv)
 	
 
 		/*
-		 *	Encrypt the Password attribute.
+		 *	Keep a copy of the the Password attribute.
 		 */
 		if ((vp = pairfind(req->vps, PW_PASSWORD)) != NULL) {
 			strNcpy(password, (char *)vp->strvalue, sizeof(vp->strvalue));
-
-			rad_pwencode((char *)vp->strvalue,
-				&(vp->length),
-				secret, (char *)req->vector);
-
 		/*
-		 *	Not there, encrypt the CHAP-Password attribute.
+		 *	Otherwise keep a copy of the CHAP-Password attribute.
 		 */
 		} else if ((vp = pairfind(req->vps, PW_CHAP_PASSWORD)) != NULL) {
 			strNcpy(password, (char *)vp->strvalue, sizeof(vp->strvalue));
-			rad_chap_encode(req, (char *) vp->strvalue, req->id, vp);
-			vp->length = 17;
-
 		} else {
 			*password = '\0';
 		}
@@ -386,19 +409,28 @@ int main(int argc, char **argv)
 			if (req->data) {
 				free(req->data);
 				req->data = NULL;
-
-				if (*password != '\0') {
-					vp = pairfind(req->vps, PW_PASSWORD);
-					if (vp) {
-						strNcpy((char *)vp->strvalue, password,
-								(vp->length)+1);
-						vp->length = strlen(password);
-					}
-				}
-
-				librad_md5_calc(req->vector, req->vector,
-						sizeof(req->vector));
 			}
+
+			librad_md5_calc(req->vector, req->vector,
+					sizeof(req->vector));
+				
+			if (*password != '\0') {
+				vp = pairfind(req->vps, PW_PASSWORD);
+				if (vp) {
+					strNcpy((char *)vp->strvalue, password, vp->length + 1);
+					vp->length = strlen(password);
+					
+					rad_pwencode((char *)vp->strvalue,
+						     &(vp->length),
+						     secret, (char *)req->vector);
+				} else if ((vp = pairfind(req->vps, PW_CHAP_PASSWORD)) != NULL) {
+					strNcpy((char *)vp->strvalue, password, vp->length + 1);
+					vp->length = strlen(password);
+					
+					rad_chap_encode(req, (char *) vp->strvalue, req->id, vp);
+					vp->length = 17;
+				}
+			} /* there WAS a password */
 			send_packet(req, &rep);
 			rad_free(&rep);
 		}
