@@ -2,7 +2,7 @@
  * valuepair.c	Valuepair functions that are radiusd-specific
  *		and as such do not belong in the library.
  *
- * Version:	$Id: valuepair.c,v 1.32 2001/03/09 20:16:38 aland Exp $
+ * Version:	$Id: valuepair.c,v 1.33 2001/08/09 15:07:32 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
 
-static const char rcsid[] = "$Id: valuepair.c,v 1.32 2001/03/09 20:16:38 aland Exp $";
+static const char rcsid[] = "$Id: valuepair.c,v 1.33 2001/08/09 15:07:32 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -528,6 +528,31 @@ static int attrcmp(void *instance, VALUE_PAIR *request, VALUE_PAIR *check,
 	return -1;
 }
 
+/*
+ *	Compare the expiration date.
+ */
+static int expirecmp(void *instance, VALUE_PAIR *request, VALUE_PAIR *check,
+		     VALUE_PAIR *check_pairs, VALUE_PAIR **reply_pairs)
+{
+	time_t now;
+
+	instance = instance;
+	request = request;	/* shut the compiler up */
+	check_pairs = check_pairs;
+	reply_pairs = reply_pairs;
+
+	/*
+	 *  FIXME!  This should be request->timestamp!
+	 */
+	now = time(NULL);
+
+	if (now <= check->lvalue) {
+		return 0;
+	}
+
+	return +1;
+}
+
 /*
  *	Register server-builtin special attributes.
  */
@@ -539,4 +564,5 @@ void pair_builtincompare_init(void)
 	paircompare_register(PW_CONNECT_RATE, PW_CONNECT_INFO, connectcmp, NULL);
 	paircompare_register(PW_CURRENT_TIME, 0, timecmp, NULL);
 	paircompare_register(PW_NO_SUCH_ATTRIBUTE, 0, attrcmp, NULL);
+	paircompare_register(PW_EXPIRATION, 0, expirecmp, NULL);
 }
