@@ -2,7 +2,7 @@
  * rlm_files.c	authorization: Find a user in the "users" file.
  *		accounting:    Write the "detail" files.
  *
- * Version:	$Id: rlm_files.c,v 1.55 2001/07/01 19:18:20 cmiller Exp $
+ * Version:	$Id: rlm_files.c,v 1.56 2001/08/16 15:01:12 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  */
 
-static const char rcsid[] = "$Id: rlm_files.c,v 1.55 2001/07/01 19:18:20 cmiller Exp $";
+static const char rcsid[] = "$Id: rlm_files.c,v 1.56 2001/08/16 15:01:12 aland Exp $";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -387,7 +387,7 @@ static int file_preacct(void *instance, REQUEST *request)
 	const char	*name;
 	VALUE_PAIR	*request_pairs;
 	VALUE_PAIR	**config_pairs;
-	VALUE_PAIR	*reply_pairs = NULL;
+	VALUE_PAIR	**reply_pairs;
 	VALUE_PAIR	*check_tmp;
 	VALUE_PAIR	*reply_tmp;
 	PAIR_LIST	*pl;
@@ -398,7 +398,8 @@ static int file_preacct(void *instance, REQUEST *request)
 	name = namepair ? (char *) namepair->strvalue : "NONE";
 	request_pairs = request->packet->vps;
 	config_pairs = &request->config_items;
-	
+	reply_pairs = &request->reply->vps;
+
 	/*
 	 *	Find the entry for the user.
 	 */
@@ -407,13 +408,13 @@ static int file_preacct(void *instance, REQUEST *request)
 		if (strcmp(name, pl->name) && strcmp(pl->name, "DEFAULT"))
 			continue;
 
-		if (paircmp(request_pairs, pl->check, &reply_pairs) == 0) {
+		if (paircmp(request_pairs, pl->check, reply_pairs) == 0) {
 			DEBUG2("    acct_users: Matched %s at %d",
 			       pl->name, pl->lineno);
 			found = 1;
 			check_tmp = paircopy(pl->check);
 			reply_tmp = paircopy(pl->reply);
-			pairmove(&reply_pairs, &reply_tmp);
+			pairmove(reply_pairs, &reply_tmp);
 			pairmove(config_pairs, &check_tmp);
 			pairfree(&reply_tmp);
 			pairfree(&check_tmp); /* should be NULL */
@@ -431,12 +432,6 @@ static int file_preacct(void *instance, REQUEST *request)
 	if (!found)
 		return RLM_MODULE_NOOP; /* on to the next module */
 
-	/*
-	 *	FIXME: log a warning if there are any reply items other than
-	 *	Fallthrough
-	 */
-	pairfree(&reply_pairs); /* Don't need these */
-
 	return RLM_MODULE_OK;
 }
 
