@@ -30,7 +30,7 @@
  *	- Added "profile_attribute" directive, which specifies user object 
  *	  attribute pointing to radiusProfile object.
  */
-static const char rcsid[] = "$Id: rlm_ldap.c,v 1.48 2001/07/17 09:17:00 pam Exp $";
+static const char rcsid[] = "$Id: rlm_ldap.c,v 1.50 2001/08/28 20:01:48 aland Exp $";
 
 #include "autoconf.h"
 
@@ -635,9 +635,9 @@ ldap_connect(void *instance, const char *dn, const char *password, int auth, int
 
 	rc = ldap_result(ld, msgid, 1, &(inst->timeout), &res);
 
-	ldap_get_option(ld, LDAP_OPT_ERROR_NUMBER, &ldap_errno);
 	if(rc < 1) {
 		DEBUG("rlm_ldap: ldap_result()");
+		ldap_get_option(ld, LDAP_OPT_ERROR_NUMBER, &ldap_errno);
 		radlog(L_ERR, "rlm_ldap: %s bind failed: %s", dn, (rc == 0) ? "timeout" : ldap_err2string(ldap_errno));
 		*result = RLM_MODULE_FAIL;
 		ldap_unbind_s(ld);
@@ -770,7 +770,7 @@ ldap_pairget(LDAP * ld, LDAPMessage * entry,
 	int             vals_idx;
 	char           *ptr;
 	TLDAP_RADIUS   *element;
-	int             token;
+	LRAD_TOKEN      token;
 	int             is_generic_attribute;
 	char            value[64];
 	VALUE_PAIR     *pairlist = NULL;
