@@ -1,7 +1,7 @@
 /*
  * rlm_realm.c	
  *
- * Version:	$Id: rlm_realm.c,v 1.31 2001/03/14 06:54:54 pacman Exp $
+ * Version:	$Id: rlm_realm.c,v 1.32 2001/06/08 16:50:09 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include "radiusd.h"
 #include "modules.h"
 
-static const char rcsid[] = "$Id: rlm_realm.c,v 1.31 2001/03/14 06:54:54 pacman Exp $";
+static const char rcsid[] = "$Id: rlm_realm.c,v 1.32 2001/06/08 16:50:09 aland Exp $";
 
 #define  REALM_FORMAT_PREFIX   0
 #define  REALM_FORMAT_SUFFIX   1
@@ -94,7 +94,7 @@ static REALM *check_for_realm(void *instance, REQUEST *request)
 	case REALM_FORMAT_SUFFIX:
 	  
 	  /* DEBUG2("  rlm_realm: Checking for suffix after \"%c\"", inst->delim[0]); */
-		realmname = strchr(username, inst->delim[0]);		
+		realmname = strrchr(username, inst->delim[0]);		
 		if (realmname) {
 			*realmname = '\0';
 			realmname++;
