@@ -3,7 +3,7 @@
  *		accounting:     Functions to write radwtmp file.
  *		Also contains handler for "Group".
  *
- * Version:	$Id: rlm_unix.c,v 1.32 2001/02/20 20:55:31 pacman Exp $
+ * Version:	$Id: rlm_unix.c,v 1.36 2001/10/01 18:22:52 hartwick Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  * Copyright 2000  Alan Curry <pacman@world.std.com>
  */
-static const char rcsid[] = "$Id: rlm_unix.c,v 1.32 2001/02/20 20:55:31 pacman Exp $";
+static const char rcsid[] = "$Id: rlm_unix.c,v 1.36 2001/10/01 18:22:52 hartwick Exp $";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -48,6 +48,11 @@ static const char rcsid[] = "$Id: rlm_unix.c,v 1.32 2001/02/20 20:55:31 pacman E
 #  include	<prot.h>
 #endif
 
+#ifdef OSFSIA
+#  include	<sia.h>
+#  include	<siad.h>
+#endif
+
 #include	"radiusd.h"
 #include	"modules.h"
 #include	"sysutmp.h"
@@ -102,6 +107,37 @@ static struct unix_instance *group_inst;
  * file) or not ("Group=" was bound to the first instance of rlm_unix */
 static int group_inst_explicit;
 
+struct passwd *fgetpwnam(const char *fname, const char *name) {
+	FILE		*file = fopen(fname, "ro");
+	struct passwd	*pwd = NULL;
+
+	if(file == NULL) return NULL;
+	do {
+		pwd = fgetpwent(file);
+		if(pwd == NULL) {
+			fclose(file);
+			return NULL;
+		}
+	} while(strcmp(name, pwd->pw_name) != 0);
+	fclose(file);
+	return pwd;
+}
+
+struct passwd *fgetgrnam(const char *fname, const char *name) {
+	FILE		*file = fopen(fname, "ro");
+	struct group	*grp = NULL;
+	if(file == NULL) return NULL;
+	do {
+		grp = fgetgrent(file);
+		if(grp == NULL) {
+			fclose(file);
+			return NULL;
+		}
+	} while(strcmp(name, grp->gr_name) != 0);
+	fclose(file);
+	return grp;
+}
+
 /*
  *	The Group = handler.
  */
@@ -123,16 +159,18 @@ static int groupcmp(void *instance, VALUE_PAIR *request, VALUE_PAIR *check,
 		return 1;
 	}
 
+	radlog(L_ERR, "group = %s", group_inst->group_file);
+
 	username = (char *)request->strvalue;
 
 	if (group_inst->cache_passwd &&
 	    (retval = H_groupcmp(group_inst->cache, check, username)) != -2)
 		return retval;
 
-	if ((pwd = getpwnam(username)) == NULL)
+	if ((pwd = fgetpwnam(group_inst->passwd_file, username)) == NULL)
 		return -1;
 
-	if ((grp = getgrnam((char *)check->strvalue)) == NULL)
+	if ((grp = fgetgrnam(group_inst->group_file, (char *)check->strvalue)) == NULL)
 		return -1;
 
 	retval = (pwd->pw_gid == grp->gr_gid) ? 0 : -1;
@@ -182,7 +220,8 @@ static int unix_instantiate(CONF_SECTION *conf, void **instance)
 		radlog(L_INFO, "HASH:  Reinitializing hash structures "
 			"and lists for caching...");
 		if ((inst->cache = unix_buildpwcache(inst->passwd_file,
-						     inst->shadow_file))==NULL)
+						     inst->shadow_file,
+						     inst->group_file))==NULL)
                 {
 			radlog(L_ERR, "HASH:  unable to create user "
 				"hash table.  disable caching and run debugs");
@@ -266,6 +305,11 @@ static int unix_authenticate(void *instance, REQUEST *request)
 #ifdef OSFC2
 	struct pr_passwd *pr_pw;
 #endif
+#ifdef OSFSIA
+	char		*info[2];
+	char		*progname = "radius";
+	SIAENTITY	*ent = NULL;
+#endif
 #ifdef HAVE_GETUSERSHELL
 	char		*shell;
 #endif
@@ -304,6 +348,24 @@ static int unix_authenticate(void *instance, REQUEST *request)
 	    (ret = H_unix_pass(inst->cache, name, passwd, &request->reply->vps)) != -2)
 		return (ret == 0) ? RLM_MODULE_OK : RLM_MODULE_REJECT;
 
+#ifdef OSFSIA
+	info[0] = progname;
+	info[1] = NULL;
+	if (sia_ses_init (&ent, 1, info, NULL, name, NULL, 0, NULL) !=
+	    SIASUCCESS)
+		return RLM_MODULE_NOTFOUND;
+	if ((ret = sia_ses_authent (NULL, passwd, ent)) != SIASUCCESS) {
+		if (ret & SIASTOP)
+			sia_ses_release (&ent);
+		return RLM_MODULE_NOTFOUND;
+	}
+	if (sia_ses_estab (NULL, ent) == SIASUCCESS) {
+		sia_ses_release (&ent);
+		return RLM_MODULE_OK;
+	}
+
+	return RLM_MODULE_NOTFOUND;
+#else /* OSFSIA */
 #ifdef OSFC2
 	if ((pr_pw = getprpwnam(name)) == NULL)
 		return RLM_MODULE_NOTFOUND;
@@ -403,6 +465,7 @@ static int unix_authenticate(void *instance, REQUEST *request)
 		return RLM_MODULE_REJECT;
 
 	return RLM_MODULE_OK;
+#endif /* OSFSIA */
 #undef inst
 }
 
@@ -489,7 +552,11 @@ static int unix_accounting(void *instance, REQUEST *request)
 	for (vp = request->packet->vps; vp; vp = vp->next) {
 		switch (vp->attribute) {
 			case PW_USER_NAME:
-				strNcpy(ut.ut_name, (char *)vp->strvalue, sizeof(ut.ut_name));
+				if (vp->length >= sizeof(ut.ut_name)) {
+					memcpy(ut.ut_name, (char *)vp->strvalue, sizeof(ut.ut_name));
+				} else {
+					strNcpy(ut.ut_name, (char *)vp->strvalue, sizeof(ut.ut_name));
+				}
 				break;
 			case PW_LOGIN_IP_HOST:
 			case PW_FRAMED_IP_ADDRESS:
@@ -597,7 +664,7 @@ static int unix_accounting(void *instance, REQUEST *request)
 /* globally exported name */
 module_t rlm_unix = {
   "System",
-  0,                            /* type: reserved */
+  RLM_TYPE_THREAD_UNSAFE,        /* type: reserved */
   unix_init,                    /* initialization */
   unix_instantiate,		/* instantiation */
   {
